@@ -17,10 +17,10 @@
   }
   )
   
-  test_that("No error is returned for valid table id", {
-    expect_no_message(get_table_info_brief("NM_42_1"))
-  }
-  )
+#  test_that("No error is returned for valid table id", {
+#    expect_no_message(get_table_info_brief("NM_42_1"))
+#  }
+#  )
   
   
   list_of_tables <- list("NM_1_1","NM_20_1","NM_99_1","NM_103_1","NM_147_1","NM_189_1","NM_210_1","NM_399_1","NM_403_1","NM_547_1","NM_1089_1")
@@ -29,4 +29,4 @@
       expect_no_message(get_table_info_brief(tab_id))
     }
     )
-  }
\ No newline at end of file
+  }
